@@ -1,5 +1,5 @@
 from calendar import timegm
-from datetime import datetime
+from datetime import datetime, timezone
 from typing import Any, Dict, List, Optional, Union
 
 from cbor2 import CBORTag
@@ -408,7 +408,7 @@ class CWT(CBORProcessor):
         if not isinstance(claims, dict):
             raise DecodeError("Failed to decode.")
 
-        now = timegm(datetime.utcnow().utctimetuple())
+        now = timegm(datetime.now(tz=timezone.utc).utctimetuple())
         if 4 in claims:  # exp
             if isinstance(claims[4], int) or isinstance(claims[4], float):
                 if claims[4] < (now - self._leeway):
@@ -427,7 +427,7 @@ class CWT(CBORProcessor):
     def _set_default_value(self, claims: Union[Dict[int, Any], bytes]):
         if isinstance(claims, bytes):
             return
-        now = timegm(datetime.utcnow().utctimetuple())
+        now = timegm(datetime.now(tz=timezone.utc).utctimetuple())
         if 4 not in claims:
             claims[4] = now + self._expires_in
         if 5 not in claims:
@@ -439,9 +439,60 @@ class CWT(CBORProcessor):
 
 # export
 _cwt = CWT()
-encode = _cwt.encode
-encode_and_mac = _cwt.encode_and_mac
-encode_and_sign = _cwt.encode_and_sign
-encode_and_encrypt = _cwt.encode_and_encrypt
-decode = _cwt.decode
-set_private_claim_names = _cwt.set_private_claim_names
+
+
+def encode(
+    claims: Union[Claims, Dict[str, Any], Dict[int, Any], bytes],
+    key: COSEKeyInterface,
+    nonce: bytes = b"",
+    recipients: Optional[List[RecipientInterface]] = None,
+    signers: List[Signer] = [],
+    tagged: bool = False,
+) -> bytes:
+
+    return _cwt.encode(claims, key, nonce, recipients, signers, tagged)
+
+
+def encode_and_mac(
+    claims: Union[Claims, Dict[int, Any], bytes],
+    key: COSEKeyInterface,
+    recipients: Optional[List[RecipientInterface]] = None,
+    tagged: bool = False,
+) -> bytes:
+
+    return _cwt.encode_and_mac(claims, key, recipients, tagged)
+
+
+def encode_and_sign(
+    claims: Union[Claims, Dict[int, Any], bytes],
+    key: Optional[COSEKeyInterface] = None,
+    signers: List[Signer] = [],
+    tagged: bool = False,
+) -> bytes:
+
+    return _cwt.encode_and_sign(claims, key, signers, tagged)
+
+
+def encode_and_encrypt(
+    claims: Union[Claims, Dict[int, Any], bytes],
+    key: COSEKeyInterface,
+    nonce: bytes = b"",
+    recipients: Optional[List[RecipientInterface]] = None,
+    tagged: bool = False,
+) -> bytes:
+
+    return _cwt.encode_and_encrypt(claims, key, nonce, recipients, tagged)
+
+
+def decode(
+    data: bytes,
+    keys: Union[COSEKeyInterface, List[COSEKeyInterface]],
+    no_verify: bool = False,
+) -> Union[Dict[int, Any], bytes]:
+
+    return _cwt.decode(data, keys, no_verify)
+
+
+def set_private_claim_names(claim_names: Dict[str, int]):
+
+    return _cwt.set_private_claim_names(claim_names)
